==> ehome-rcm-0.12.3.tgz: package/es/form-view/fields/File/index.js <==
import "antd-mobile/es/modal/style";
import _Modal from "antd-mobile/es/modal";
import "antd-mobile/es/icon/style";
import _Icon from "antd-mobile/es/icon";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { PureComponent, Component } from 'react';
import PropTypes from 'prop-types';
import moment from 'moment';
import getIconByFileName from './getIconByFileName';

var FileField =
/*#__PURE__*/
function (_ref) {
  _inherits(FileField, _ref);

  function FileField(props) {
    var _this;

    _classCallCheck(this, FileField);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(FileField).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "getFileSizeText", function (fileSize) {
      var text = '';

      if (fileSize >= 1024 * 1024) {
        text = "".concat((fileSize / 1024 / 1024).toFixed(2), "MB");
      } else if (fileSize >= 1024) {
        text = "".concat((fileSize / 1024).toFixed(2), "KB");
      } else {
        text = "".concat(fileSize, "B");
      }

      return text;
    });

    _defineProperty(_assertThisInitialized(_this), "clickField", function () {
      var scrollTop = document.body.scrollTop || document.documentElement.scrollTop;
      var rootElement = document.getElementById('root'); // 使 root 脱离文档流

      rootElement.classList.add('dialog-open'); // 把脱离文档流的 root 拉上去，否则页面会回到顶部！

      rootElement.style.top = "".concat(-scrollTop, "px");

      _this.setState({
        visible: true,
        bodyScrollTop: scrollTop
      });
    });

    _defineProperty(_assertThisInitialized(_this), "closeModal", function (e) {
      e.stopPropagation();
      var bodyScrollTop = _this.state.bodyScrollTop;
      var rootElement = document.getElementById('root');
      rootElement.classList.remove('dialog-open'); // 滚回到老地方

      document.body.scrollTop = bodyScrollTop;
      document.documentElement.scrollTop = bodyScrollTop;

      _this.setState({
        visible: false
      });
    });

    _this.state = {
      visible: false,
      bodyScrollTop: 0
    };
    return _this;
  }

  _createClass(FileField, [{
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      // root回到文档流中
      var rootElement = document.getElementById('root');
      rootElement.classList.remove('dialog-open');
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props = this.props,
          field = _this$props.field,
          layoutType = _this$props.layoutType,
          commonPrefixCls = _this$props.commonPrefixCls,
          labelWidth = _this$props.labelWidth,
          nullDisplayType = _this$props.nullDisplayType;
      var visible = this.state.visible; // eslint-disable-next-line prefer-const

      var fieldName = field.fieldName,
          _field$fieldValue = field.fieldValue,
          fieldValue = _field$fieldValue === void 0 ? '{}' : _field$fieldValue;
      fieldValue = JSON.parse(fieldValue);
      var _fieldValue = fieldValue,
          _fieldValue$files = _fieldValue.files,
          files = _fieldValue$files === void 0 ? [] : _fieldValue$files;
      var prefixCls = 'eh-field-view-file';
      var modalPrefixCls = "".concat(prefixCls, "-modal");
      prefixCls += layoutType === 0 ? '-hor' : '-ver';
      var hidden = nullDisplayType === 1 && !files.length;
      return hidden ? null : React.createElement("div", {
        className: prefixCls,
        onClick: !files.length || layoutType !== 0 ? null : this.clickField
      }, React.createElement("div", {
        className: "".concat(commonPrefixCls, "-name"),
        style: {
          width: labelWidth
        }
      }, fieldName), React.createElement("div", {
        className: "".concat(commonPrefixCls, "-value")
      }, files.length ? layoutType === 0 ? React.createElement("div", {
        className: "".concat(prefixCls, "-info")
      }, React.createElement("div", {
        className: "".concat(prefixCls, "-info-text")
      }, files.length, "\u4E2A\u9644\u4EF6"), React.createElement("i", {
        className: "".concat(prefixCls, "-info-icon iconfont icon-form_cell_arrow_icon")
      })) : React.createElement("div", {
        className: "".concat(prefixCls, "-list")
      }, files.map(function (file, index) {
        return React.createElement("div", {
          key: index,
          className: "".concat(prefixCls, "-file")
        }, React.createElement("div", {
          className: "".concat(prefixCls, "-file-icon")
        }, React.createElement("img", {
          src: getIconByFileName(file.fileName),
          alt: ""
        })), React.createElement("div", {
          className: "".concat(prefixCls, "-file-content")
        }, React.createElement("div", {
          className: "".concat(prefixCls, "-file-name")
        }, file.fileName), React.createElement("div", {
          className: "".concat(prefixCls, "-file-detail")
        }, React.createElement("div", {
          className: "".concat(prefixCls, "-file-time")
        }, moment(file.uploadTime).format('YYYY-MM-DD HH:mm')), React.createElement("div", {
          className: "".concat(prefixCls, "-file-size")
        }, _this2.getFileSizeText(file.fileSize)))));
      })) : '无'), React.createElement(_Modal, {
        popup: true,
        visible: visible,
        onClose: this.closeModal,
        animationType: "slide-up"
      }, React.createElement("div", {
        className: modalPrefixCls
      }, React.createElement("div", {
        className: "".concat(modalPrefixCls, "-header")
      }, React.createElement(_Icon, {
        type: "cross",
        onClick: this.closeModal
      }), React.createElement("span", {
        className: "".concat(modalPrefixCls, "-header-text")
      }, "".concat(fieldName, "(").concat(files.length, ")"))), React.createElement("div", {
        className: "".concat(modalPrefixCls, "-content")
      }, files.map(function (file, index) {
        return React.createElement("div", {
          key: index,
          className: "".concat(modalPrefixCls, "-item")
        }, React.createElement("div", {
          className: "".concat(modalPrefixCls, "-item-icon")
        }, React.createElement("img", {
          src: getIconByFileName(file.fileName),
          alt: ""
        })), React.createElement("div", {
          className: "".concat(modalPrefixCls, "-item-content")
        }, React.createElement("div", {
          className: "".concat(modalPrefixCls, "-item-name")
        }, file.fileName), React.createElement("div", {
          className: "".concat(modalPrefixCls, "-item-detail")
        }, React.createElement("div", {
          className: "".concat(modalPrefixCls, "-item-time")
        }, moment(file.uploadTime).format('YYYY-MM-DD HH:mm')), React.createElement("div", {
          className: "".concat(modalPrefixCls, "-item-size")
        }, _this2.getFileSizeText(file.fileSize)))));
      })))));
    }
  }]);

  return FileField;
}(PureComponent || Component);

FileField.PropTypes = {
  field: PropTypes.object,
  // 字段数据
  layoutType: PropTypes.number,
  // 字段的布局类型：0 - 左右结构（默认），1 - 上下结构
  nullDisplayType: PropTypes.number,
  // 字段值为空时，显示的类型：0 - 显示'无'（默认），1 - 字段不显示
  commonPrefixCls: PropTypes.string,
  // 所有字段通用的 prefixCls
  labelWidth: PropTypes.number // label的宽度

};
FileField.defaultProps = {
  field: {}
};
export default FileField;

==> ehome-rcm-0.13.10.tgz: package/es/form-view/fields/File/index.js <==
import "antd-mobile/es/modal/style";
import _Modal from "antd-mobile/es/modal";
import "antd-mobile/es/icon/style";
import _Icon from "antd-mobile/es/icon";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { PureComponent, Component } from 'react';
import PropTypes from 'prop-types';
import moment from 'moment';
import getIconByFileName from './getIconByFileName';

var FileField =
/*#__PURE__*/
function (_ref) {
  _inherits(FileField, _ref);

  function FileField(props) {
    var _this;

    _classCallCheck(this, FileField);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(FileField).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "getFileSizeText", function (fileSize) {
      var text = '';

      if (fileSize >= 1024 * 1024) {
        text = "".concat((fileSize / 1024 / 1024).toFixed(2), "MB");
      } else if (fileSize >= 1024) {
        text = "".concat((fileSize / 1024).toFixed(2), "KB");
      } else {
        text = "".concat(fileSize, "B");
      }

      return text;
    });

    _defineProperty(_assertThisInitialized(_this), "clickField", function () {
      var scrollTop = document.body.scrollTop || document.documentElement.scrollTop;
      var rootElement = document.getElementById('root'); // 使 root 脱离文档流

      rootElement.classList.add('dialog-open'); // 把脱离文档流的 root 拉上去，否则页面会回到顶部！

      rootElement.style.top = "".concat(-scrollTop, "px");

      _this.setState({
        visible: true,
        bodyScrollTop: scrollTop
      });
    });

    _defineProperty(_assertThisInitialized(_this), "closeModal", function (e) {
      e.stopPropagation();
      var bodyScrollTop = _this.state.bodyScrollTop;
      var rootElement = document.getElementById('root');
      rootElement.classList.remove('dialog-open'); // 滚回到老地方

      document.body.scrollTop = bodyScrollTop;
      document.documentElement.scrollTop = bodyScrollTop;

      _this.setState({
        visible: false
      });
    });

    _this.state = {
      visible: false,
      bodyScrollTop: 0
    };
    return _this;
  }

  _createClass(FileField, [{
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      // root回到文档流中
      var rootElement = document.getElementById('root');
      rootElement.classList.remove('dialog-open');
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props = this.props,
          field = _this$props.field,
          layoutType = _this$props.layoutType,
          commonPrefixCls = _this$props.commonPrefixCls,
          labelWidth = _this$props.labelWidth,
          nullDisplayType = _this$props.nullDisplayType;
      var visible = this.state.visible; // eslint-disable-next-line prefer-const

      var fieldName = field.fieldName,
          _field$fieldValue = field.fieldValue,
          fieldValue = _field$fieldValue === void 0 ? '{}' : _field$fieldValue;
      fieldValue = JSON.parse(fieldValue);
      var _fieldValue = fieldValue,
          _fieldValue$files = _fieldValue.files,
          files = _fieldValue$files === void 0 ? [] : _fieldValue$files;
      var prefixCls = 'eh-field-view-file';
      var modalPrefixCls = "".concat(prefixCls, "-modal");
      prefixCls += layoutType === 0 ? '-hor' : '-ver';
      var hidden = nullDisplayType === 1 && !files.length;
      return hidden ? null : React.createElement("div", {
        className: prefixCls,
        onClick: !files.length || layoutType !== 0 ? null : this.clickField
      }, React.createElement("div", {
        className: "".concat(commonPrefixCls, "-name"),
        style: {
          width: labelWidth
        }
      }, fieldName), React.createElement("div", {
        className: "".concat(commonPrefixCls, "-value")
      }, files.length ? layoutType === 0 ? React.createElement("div", {
        className: "".concat(prefixCls, "-info")
      }, React.createElement("div", {
        className: "".concat(prefixCls, "-info-text")
      }, files.length, "\u4E2A\u9644\u4EF6"), React.createElement("i", {
        className: "".concat(prefixCls, "-info-icon eh-iconfont")
      }, "\uE773")) : React.createElement("div", {
        className: "".concat(prefixCls, "-list")
      }, files.map(function (file, index) {
        return React.createElement("div", {
          key: index,
          className: "".concat(prefixCls, "-file")
        }, React.createElement("div", {
          className: "".concat(prefixCls, "-file-icon")
        }, React.createElement("img", {
          src: getIconByFileName(file.fileName),
          alt: ""
        })), React.createElement("div", {
          className: "".concat(prefixCls, "-file-content")
        }, React.createElement("div", {
          className: "".concat(prefixCls, "-file-name")
        }, file.fileName), React.createElement("div", {
          className: "".concat(prefixCls, "-file-detail")
        }, React.createElement("div", {
          className: "".concat(prefixCls, "-file-time")
        }, moment(file.uploadTime).format('YYYY-MM-DD HH:mm')), React.createElement("div", {
          className: "".concat(prefixCls, "-file-size")
        }, _this2.getFileSizeText(file.fileSize)))));
      })) : '无'), React.createElement(_Modal, {
        popup: true,
        visible: visible,
        onClose: this.closeModal,
        animationType: "slide-up"
      }, React.createElement("div", {
        className: modalPrefixCls
      }, React.createElement("div", {
        className: "".concat(modalPrefixCls, "-header")
      }, React.createElement(_Icon, {
        type: "cross",
        onClick: this.closeModal
      }), React.createElement("span", {
        className: "".concat(modalPrefixCls, "-header-text")
      }, "".concat(fieldName, "(").concat(files.length, ")"))), React.createElement("div", {
        className: "".concat(modalPrefixCls, "-content")
      }, files.map(function (file, index) {
        return React.createElement("div", {
          key: index,
          className: "".concat(modalPrefixCls, "-item")
        }, React.createElement("div", {
          className: "".concat(modalPrefixCls, "-item-icon")
        }, React.createElement("img", {
          src: getIconByFileName(file.fileName),
          alt: ""
        })), React.createElement("div", {
          className: "".concat(modalPrefixCls, "-item-content")
        }, React.createElement("div", {
          className: "".concat(modalPrefixCls, "-item-name")
        }, file.fileName), React.createElement("div", {
          className: "".concat(modalPrefixCls, "-item-detail")
        }, React.createElement("div", {
          className: "".concat(modalPrefixCls, "-item-time")
        }, moment(file.uploadTime).format('YYYY-MM-DD HH:mm')), React.createElement("div", {
          className: "".concat(modalPrefixCls, "-item-size")
        }, _this2.getFileSizeText(file.fileSize)))));
      })))));
    }
  }]);

  return FileField;
}(PureComponent || Component);

FileField.PropTypes = {
  field: PropTypes.object,
  // 字段数据
  layoutType: PropTypes.number,
  // 字段的布局类型：0 - 左右结构（默认），1 - 上下结构
  nullDisplayType: PropTypes.number,
  // 字段值为空时，显示的类型：0 - 显示'无'（默认），1 - 字段不显示
  commonPrefixCls: PropTypes.string,
  // 所有字段通用的 prefixCls
  labelWidth: PropTypes.number // label的宽度

};
FileField.defaultProps = {
  field: {}
};
export default FileField;
